**** Regressions for the Paper "The origins of agricultural inheritance traditions" in JCE ***

clear all
cap log close
set more off

* set your working directory here: cd "xxx"
use explain_inheritance_bw.dta


global geo ele_mean crop_mean
global hist_med1 roman_road_density hre_fragmentation hre_instability church_share_1555 imperial_share_1555  württemberg1789  imperial_distance_1555 mp_1500  
global histpre  germanic_grave_dummy neolitihicum_share altsiedel_dummy
global earlymed  set_5


** Table 3:  Determinants of Equal Partition in Baden-Württemberg**

probit freiteilungsgebiet $geo, cluster(kreis_id)
margins,dydx(*) post
outreg2 using Table3, excel bdec(4) sdec(3)

probit freiteilungsgebiet $histpre $earlymed, cluster(kreis_id)
margins,dydx(*) post
outreg2 using Table3, excel bdec(4) sdec(3)

probit freiteilungsgebiet $hist_med1 , cluster(kreis_id)
margins,dydx(*) post
outreg2 using Table3, excel bdec(4) sdec(3)


probit freiteilungsgebiet $geo $histpre $earlymed $hist_med1  , cluster(kreis_id)
margins,dydx(*) post
outreg2 using Table3, excel bdec(4) sdec(3)


*** Table 4: Robustness Checks ***

*** Without Forest Area***

probit freiteilungsgebiet $geo $histpre $earlymed $hist_med1 if set_6==0 , cluster(kreis_id)
margins,dydx(*) post
outreg2 using Table4, excel bdec(4) sdec(3)

****  Without Black Forest *****

probit freiteilungsgebiet $geo $histpre $earlymed $hist_med1 if western_border==0 , cluster(kreis_id)
margins,dydx(*) post
outreg2 using Table4, excel bdec(4) sdec(3)


/* This is in a footnote:

**** Conley SEs with Logit Regressions ***

use "/Users/fabia/Dropbox/Publikationen/Inheritance Rules and Inequality in Baden-Württemberg/Stata/inh_bw_gemeinden_merged_fabi_conley.dta", replace

log using conley, replace
drop epsilon-dis2
x_ols latitude longitude cutoff1 cutoff2  freiteilungsgebiet const crop_mean ele_mean  roman_road_density germanic_grave_dummy neolitihicum_share altsiedel_dummy set_5 church_share_1555 imperial_share_1555  württemberg1789  imperial_distance_1555 hre_fragmentation hre_instability mp_1500 ,xreg(15) coord(2)

outreg2 using Table2Robustness, excel bdec(4) sdec(3)
drop epsilon-dis2

xgmlt latitude longitude cutoff1 cutoff2  freiteilungsgebiet const crop_mean ele_mean  roman_road_density germanic_grave_dummy neolitihicum_share altsiedel_dummy set_5 church_share_1555 imperial_share_1555  württemberg1789  imperial_distance_1555 hre_fragmentation hre_instability mp_1500 ,xreg(15) coord(2)

cap log close
use "/Users/fabia/Dropbox/Publikationen/Inheritance Rules and Inequality in Baden-Württemberg/Stata/inh_bw_gemeinden_merged_fabi.dta", replace
*/

**** States ***

reg freiteilungsgebiet $geo $histpre $earlymed $hist_med1 i.state_1789, cluster(kreis_id)
outreg2 using Table4, excel bdec(4) sdec(3)

*** With historical wine-growing

probit freiteilungsgebiet $geo weinbau_dummy_hist $histpre $earlymed $hist_med1, cluster(kreis_id)
margins,dydx(*) post
outreg2 using Table4, excel bdec(4) sdec(3)

*** With equal partition in 1950 and without transitional forms ***

probit freiteilung $geo $histpre $earlymed $hist_med1 if inheritance==1 | inheritance==2, cluster(kreis_id)
margins,dydx(*) post
outreg2 using Table4, excel bdec(4) sdec(3)


*** Additional check ***

probit freiteilungsgebiet $geo settled_early set5_dist $earlymed $hist_med1  , cluster(kreis_id)
margins,dydx(*) post
outreg2 using Table4, excel bdec(4) sdec(3)



**** Table 5: Equal Partition in Kingdom of Württemberg in 1905 ****

use explaining_inheritance_1905.dta

probit realteilung $geo, cluster(oberamt_id)
margins,dydx(*) post
outreg2 using Table5, excel bdec(4) sdec(3)

probit realteilung $histpre $earlymed, cluster(oberamt_id)
margins,dydx(*) post
outreg2 using Table5, excel bdec(4) sdec(3)

probit realteilung $hist_med1 , cluster(oberamt_id)
margins,dydx(*) post
outreg2 using Table5, excel bdec(4) sdec(3)

probit realteilung $geo $histpre $earlymed $hist_med1  , cluster(oberamt_id)
margins,dydx(*) post
outreg2 using Table5, excel bdec(4) sdec(3)



/* Appendix only: 

*** Table A.5: Deserted Villages and Equal Partition ***

probit wüstungen_ma freiteilungsgebiet rug_mean $geo, cluster(kreis_id)
margins,dydx(*) post
outreg2 using TableA5, excel bdec(4) sdec(3)


probit wüstungen_ma freiteilungsgebiet rug_mean germanic_grave_dummy neolitihicum_share roman_road_density, cluster(kreis_id)
margins,dydx(*) post
outreg2 using TableA5, excel bdec(4) sdec(3)


probit wüstungen_ma freiteilungsgebiet rug_mean $geo germanic_grave_dummy neolitihicum_share roman_road_density set_5 blackdeath, cluster(kreis_id)
margins,dydx(*) post
outreg2 using TableA5, excel bdec(4) sdec(3)


*** Table A.6: Explaining Changes of Inheritance Traditions***

probit change_new $geo, cluster(kreis_id)
margins,dydx(*) post
outreg2 using TableA6, excel bdec(4) sdec(3)

probit change_new $histpre $earlymed, cluster(kreis_id)
margins,dydx(*) post
outreg2 using TableA6, excel bdec(4) sdec(3)

probit change_new $hist_med1 , cluster(kreis_id)
margins,dydx(*) post
outreg2 using TableA6, excel bdec(4) sdec(3)

probit change_new $geo $histpre $earlymed $hist_med1 , cluster(kreis_id)
margins,dydx(*) post
outreg2 using TableA6, excel bdec(4) sdec(3)

probit change_new $geo $histpre $earlymed $hist_med1 n_share_change_new exklave_freiteilung exklave_anerbenrecht lnpopdens39  nebenregional_dummy haupt_dummy dist_frei_pos, cluster(kreis_id)
margins,dydx(*) post
outreg2 using TableA6, excel bdec(4) sdec(3)



